- test:
    timeout:
      minutes: {{ timeout }}
    definitions:
    - repository: https://github.com/Linaro/test-definitions.git
{%if device.name != 'ssh-device' %}
      lava-signal: kmsg
{% endif %}
      from: git
      branch: master
      path: automated/linux/peripherals/{{ name }}.yaml
      name: {{ name }}

